Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(63)

Unified Diff: ios/chrome/browser/payments/shipping_option_selection_view_controller_unittest.mm

Issue 2710683012: [Payment Request] Payment request summary view pending state (Closed)
Patch Set: rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/chrome/browser/payments/shipping_option_selection_view_controller.mm ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/chrome/browser/payments/shipping_option_selection_view_controller_unittest.mm
diff --git a/ios/chrome/browser/payments/shipping_option_selection_view_controller_unittest.mm b/ios/chrome/browser/payments/shipping_option_selection_view_controller_unittest.mm
index 370cf959a0a590a24d376443a3a95f9216312b05..973ab11b967ff42224426a58774d99ee4b6a556e 100644
--- a/ios/chrome/browser/payments/shipping_option_selection_view_controller_unittest.mm
+++ b/ios/chrome/browser/payments/shipping_option_selection_view_controller_unittest.mm
@@ -87,8 +87,8 @@ TEST_F(ShippingOptionSelectionViewControllerTest, TestModel) {
item = GetCollectionViewItem(0, 0);
EXPECT_TRUE([item isMemberOfClass:[PaymentsTextItem class]]);
- // Test the loading state.
- [GetShippingOptionSelectionViewController() setIsLoading:YES];
+ // Test the pending state.
+ [GetShippingOptionSelectionViewController() setPending:YES];
[GetShippingOptionSelectionViewController() loadModel];
ASSERT_EQ(1, NumberOfSections());
« no previous file with comments | « ios/chrome/browser/payments/shipping_option_selection_view_controller.mm ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698